@@ -3,6 +3,8 @@ import csv
 import gzip
 import json
 import shodan
+from tldextract import extract
+from ipaddress import ip_address
 
 from collections import defaultdict
 from operator import itemgetter
@@ -125,9 +127,21 @@ def alert_domain(domain, triggers):
     try:
         # Grab a list of IPs for the domain
         domain = domain.lower()
+        domain_parse = extract(domain)
         click.secho('Looking up domain information...', dim=True)
         info = api.dns.domain_info(domain, type='A')
-        domain_ips = set([record['value'] for record in info['data']])
+
+        if domain_parse.subdomain:
+            domain_ips = set([record['value'] for record in info['data']
+                              if record['subdomain'] == domain_parse.subdomain and
+                              not ip_address(record['value']).is_private])
+        else:
+            domain_ips = set([record['value'] for record in info['data']
+                              if not ip_address(record['value']).is_private])
+
+        if not domain_ips:
+            raise click.ClickException('No external IPs were found to be associated with this domain. '
+                                       'No alert was created.')
 
         # Create the actual alert
         click.secho('Creating alert...', dim=True)
